@@ -21,9 +21,10 @@ use Mojo::Base -base;
 use Mojo::JSON 'encode_json';
 use Mojo::Message::Response;
 use Scalar::Util 'blessed';
-use Swagger2::SchemaValidator;
 use constant NO_DESCRIPTION => 'No description.';
 
+require Swagger2;
+
 my $MOJO_MESSAGE_RESPONSE = Mojo::Message::Response->new;
 
 =head1 METHODS
@@ -111,9 +112,7 @@ sub _path_request_to_string {
       push @table, [$p->{name}, 'body', 'schema', 'Yes', $p->{description}];
     }
     else {
-      push @table,
-        [@$p{qw( name in type )}, Swagger2::SchemaValidator::_is_true($p->{required}) ? 'Yes' : 'No',
-        $p->{description}];
+      push @table, [@$p{qw( name in type )}, Swagger2::_is_true($p->{required}) ? 'Yes' : 'No', $p->{description}];
     }
   }
 
@@ -366,7 +365,7 @@ sub _status_code_to_string {
 
 sub _stringify {
   my ($k, $obj) = @_;
-  return 'required' if $k eq 'required'   and Swagger2::SchemaValidator::_is_true($obj->{$k});
+  return 'required' if $k eq 'required'   and Swagger2::_is_true($obj->{$k});
   return "$k=true"  if blessed $obj->{$k} and $obj->{$k} eq Mojo::JSON->true;
   return "$k=false" if blessed $obj->{$k} and $obj->{$k} eq Mojo::JSON->false;
   return sprintf '%s=%s', $k, encode_json $obj->{$k} if ref $obj->{$k};
